@@ -532,7 +532,7 @@ func (clients *clientsContainer) check(c *Client) (err error) {
 		} else if err = dnsforward.ValidateClientID(id); err == nil {
 			c.IDs[i] = id
 		} else {
-			return fmt.Errorf("invalid client id at index %d: %q", i, id)
+			return fmt.Errorf("invalid clientid at index %d: %q", i, id)
 		}
 	}
 
@@ -783,17 +783,14 @@ func (clients *clientsContainer) addFromHostsFile(hosts *netutil.IPMap) {
 
 	n := 0
 	hosts.Range(func(ip net.IP, v interface{}) (cont bool) {
-		hosts, ok := v.(*aghnet.Hosts)
+		hosts, ok := v.(*stringutil.Set)
 		if !ok {
 			log.Error("dns: bad type %T in ipToRC for %s", v, ip)
 
 			return true
 		}
 
-		if clients.addHostLocked(ip, hosts.Main, ClientSourceHostsFile) {
-			n++
-		}
-		hosts.Aliases.Range(func(name string) (cont bool) {
+		hosts.Range(func(name string) (cont bool) {
 			if clients.addHostLocked(ip, name, ClientSourceHostsFile) {
 				n++
 			}
