@@ -2,7 +2,6 @@
 package querylog
 
 import (
-	"errors"
 	"fmt"
 	"net"
 	"os"
@@ -10,8 +9,11 @@ import (
 	"sync"
 	"time"
 
-	"github.com/AdguardTeam/AdGuardHome/internal/dnsfilter"
+	"github.com/AdguardTeam/AdGuardHome/internal/aghnet"
+	"github.com/AdguardTeam/AdGuardHome/internal/filtering"
+	"github.com/AdguardTeam/golibs/errors"
 	"github.com/AdguardTeam/golibs/log"
+	"github.com/AdguardTeam/golibs/timeutil"
 	"github.com/miekg/dns"
 )
 
@@ -35,6 +37,8 @@ type queryLog struct {
 	fileFlushLock sync.Mutex // synchronize a file-flushing goroutine and main thread
 	flushPending  bool       // don't start another goroutine while the previous one is still running
 	fileWriteLock sync.Mutex
+
+	anonymizer *aghnet.IPMut
 }
 
 // ClientProto values are names of the client protocols.
@@ -42,9 +46,9 @@ type ClientProto string
 
 // Client protocol names.
 const (
-	ClientProtoDOH      ClientProto = "doh"
-	ClientProtoDOQ      ClientProto = "doq"
-	ClientProtoDOT      ClientProto = "dot"
+	ClientProtoDoH      ClientProto = "doh"
+	ClientProtoDoQ      ClientProto = "doq"
+	ClientProtoDoT      ClientProto = "dot"
 	ClientProtoDNSCrypt ClientProto = "dnscrypt"
 	ClientProtoPlain    ClientProto = ""
 )
@@ -54,9 +58,9 @@ const (
 func NewClientProto(s string) (cp ClientProto, err error) {
 	switch cp = ClientProto(s); cp {
 	case
-		ClientProtoDOH,
-		ClientProtoDOQ,
-		ClientProtoDOT,
+		ClientProtoDoH,
+		ClientProtoDoQ,
+		ClientProtoDoT,
 		ClientProtoDNSCrypt,
 		ClientProtoPlain:
 
@@ -71,7 +75,6 @@ type logEntry struct {
 	// client is the found client information, if any.
 	client *Client
 
-	IP   net.IP    `json:"IP"` // Client IP
 	Time time.Time `json:"T"`
 
 	QHost  string `json:"QH"`
@@ -84,9 +87,15 @@ type logEntry struct {
 	Answer     []byte `json:",omitempty"` // sometimes empty answers happen like binerdunt.top or rev2.globalrootservers.net
 	OrigAnswer []byte `json:",omitempty"`
 
-	Result   dnsfilter.Result
-	Elapsed  time.Duration
-	Upstream string `json:",omitempty"` // if empty, means it was cached
+	Result   filtering.Result
+	Upstream string `json:",omitempty"`
+
+	IP net.IP `json:"IP"`
+
+	Elapsed time.Duration
+
+	Cached            bool `json:",omitempty"`
+	AuthenticatedData bool `json:"AD,omitempty"`
 }
 
 func (l *queryLog) Start() {
@@ -100,8 +109,17 @@ func (l *queryLog) Close() {
 	_ = l.flushLogBuffer(true)
 }
 
-func checkInterval(days uint32) bool {
-	return days == 1 || days == 7 || days == 30 || days == 90
+func checkInterval(ivl time.Duration) (ok bool) {
+	// The constants for possible values of query log's rotation interval.
+	const (
+		quarterDay  = timeutil.Day / 4
+		day         = timeutil.Day
+		week        = timeutil.Day * 7
+		month       = timeutil.Day * 30
+		threeMonths = timeutil.Day * 90
+	)
+
+	return ivl == quarterDay || ivl == day || ivl == week || ivl == month || ivl == threeMonths
 }
 
 func (l *queryLog) WriteDiskConfig(c *Config) {
@@ -132,14 +150,12 @@ func (l *queryLog) clear() {
 	log.Debug("Query log: cleared")
 }
 
-func (l *queryLog) Add(params AddParams) {
-	var err error
-
+func (l *queryLog) Add(params *AddParams) {
 	if !l.conf.Enabled {
 		return
 	}
 
-	err = params.validate()
+	err := params.validate()
 	if err != nil {
 		log.Error("querylog: adding record: %s, skipping", err)
 
@@ -147,24 +163,31 @@ func (l *queryLog) Add(params AddParams) {
 	}
 
 	if params.Result == nil {
-		params.Result = &dnsfilter.Result{}
+		params.Result = &filtering.Result{}
 	}
 
 	now := time.Now()
+	q := params.Question.Question[0]
 	entry := logEntry{
-		IP:   l.getClientIP(params.ClientIP),
 		Time: now,
 
-		Result:      *params.Result,
-		Elapsed:     params.Elapsed,
-		Upstream:    params.Upstream,
+		QHost:  strings.ToLower(q.Name[:len(q.Name)-1]),
+		QType:  dns.Type(q.Qtype).String(),
+		QClass: dns.Class(q.Qclass).String(),
+
 		ClientID:    params.ClientID,
 		ClientProto: params.ClientProto,
+
+		Result:   *params.Result,
+		Upstream: params.Upstream,
+
+		IP: params.ClientIP,
+
+		Elapsed: params.Elapsed,
+
+		Cached:            params.Cached,
+		AuthenticatedData: params.AuthenticatedData,
 	}
-	q := params.Question.Question[0]
-	entry.QHost = strings.ToLower(q.Name[:len(q.Name)-1]) // remove the last dot
-	entry.QType = dns.Type(q.Qtype).String()
-	entry.QClass = dns.Class(q.Qclass).String()
 
 	if params.Answer != nil {
 		var a []byte
@@ -197,6 +220,10 @@ func (l *queryLog) Add(params AddParams) {
 	if !l.conf.FileEnabled {
 		if len(l.buffer) > int(l.conf.MemSize) {
 			// writing to file is disabled - just remove the oldest entry from array
+			//
+			// TODO(a.garipov): This should be replaced by a proper ring buffer,
+			// but it's currently difficult to do that.
+			l.buffer[0] = nil
 			l.buffer = l.buffer[1:]
 		}
 	} else if !l.flushPending {
