@@ -39,8 +39,25 @@ is_command() {
 }
 
 # Function is_little_endian checks if the CPU is little-endian.
+#
+# See https://serverfault.com/a/163493/267530.
 is_little_endian() {
-	[ "$( head -c 6 /bin/sh | tail -c 1 )" = "$( printf '\001' )" ]
+	# The ASCII character "I" has the octal code of 111.  In the two-byte octal
+	# display mode (-o), hexdump will print it either as "000111" on a little
+	# endian system or as a "111000" on a big endian one.  Return the sixth
+	# character to compare it against the number '1'.
+	#
+	# Do not use echo -n, because its behavior in the presence of the -n flag is
+	# explicitly implementation-defined in POSIX.  Use hexdump instead of od,
+	# because OpenWrt and its derivatives have the former but not the latter.
+	is_little_endian_result="$(
+		printf 'I'\
+			| hexdump -o\
+			| awk '{ print substr($2, 6, 1); exit; }'
+	)"
+	readonly is_little_endian_result
+
+	[ "$is_little_endian_result" -eq '1' ]
 }
 
 # Function check_required checks if the required software is available on the
@@ -384,16 +401,15 @@ rerun_with_root() {
 
 	log 'restarting with root privileges'
 	
-	# Group curl together with an echo, so that if curl fails before
-	# producing any output, the echo prints an exit command for the
-	# following shell to execute to prevent it from getting an empty input
-	# and exiting with a zero code in that case.
+	# Group curl together with an echo, so that if curl fails before producing
+	# any output, the echo prints an exit command for the following shell to
+	# execute to prevent it from getting an empty input and exiting with a zero
+	# code in that case.
 	{ curl -L -S -s "$script_url" || echo 'exit 1'; }\
 		| $sudo_cmd sh -s -- -c "$channel" -C "$cpu" -O "$os" -o "$out_dir" "$r" "$u" "$v"
 
-	# Exit the script.  Since if the code of the previous pipeline is
-	# non-zero, the execution won't reach this point thanks to set -e, exit
-	# with zero.
+	# Exit the script.  Since if the code of the previous pipeline is non-zero,
+	# the execution won't reach this point thanks to set -e, exit with zero.
 	exit 0
 }
 
@@ -483,11 +499,7 @@ handle_existing() {
 
 # Function install_service tries to install AGH as service.
 install_service() {
-	# Installing as root is required at least on FreeBSD.
-	#
-	# TODO(e.burkov): Think about AGH's output suppressing with no verbose
-	# flag.
-	if ( cd "$agh_dir" && $sudo_cmd ./AdGuardHome -s install )
+	if ( cd "$agh_dir" && ./AdGuardHome -s install )
 	then
 		return 0
 	fi
